==> jc-1.4.0.tar.gz: polyglot/lex/InputElement.h <==
// abstract class polyglot.lex.InputElement

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7a33f1a8ee1337b0 polyglot_lex_InputElement

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_lex_InputElement_H_
#define _JC_polyglot_lex_InputElement_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_lex_InputElement$sub_refs	_jc_polyglot_lex_InputElement$sub_refs;
typedef struct _jc_polyglot_lex_InputElement$sub_nonrefs	_jc_polyglot_lex_InputElement$sub_nonrefs;
typedef struct _jc_polyglot_lex_InputElement$refs	_jc_polyglot_lex_InputElement$refs;
typedef struct _jc_polyglot_lex_InputElement$nonrefs	_jc_polyglot_lex_InputElement$nonrefs;
typedef struct _jc_polyglot_lex_InputElement$object	_jc_polyglot_lex_InputElement$object;

typedef const struct _jc_polyglot_lex_InputElement$vmethods	_jc_polyglot_lex_InputElement$vmethods;
typedef const struct _jc_polyglot_lex_InputElement$vtable	_jc_polyglot_lex_InputElement$vtable;
typedef const struct _jc_polyglot_lex_InputElement$vtype	_jc_polyglot_lex_InputElement$vtype;

// Constructors
extern void _jc_polyglot_lex_InputElement$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_lex_InputElement$object *);

// Virtual methods structure
struct _jc_polyglot_lex_InputElement$vmethods {
};

// Vtable
struct _jc_polyglot_lex_InputElement$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_InputElement$vmethods	polyglot_lex_InputElement;
};

// Vtype
struct _jc_polyglot_lex_InputElement$vtype {
	_jc_type			type;
	_jc_polyglot_lex_InputElement$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_InputElement$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_InputElement$refs {
    _jc_polyglot_lex_InputElement$sub_refs	polyglot_lex_InputElement;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_InputElement$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_InputElement$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_InputElement$sub_nonrefs	polyglot_lex_InputElement;
};

// Object instance structure
struct _jc_polyglot_lex_InputElement$object {
	_jc_polyglot_lex_InputElement$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_InputElement$vtype	*vtype;
	_jc_polyglot_lex_InputElement$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_InputElement$vtype _jc_polyglot_lex_InputElement$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_InputElement, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_InputElement$class_object;

#endif	/* _JC_polyglot_lex_InputElement_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/InputElement.h <==
// abstract class polyglot.lex.InputElement

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7a33f1a8ee1337b0 polyglot_lex_InputElement

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_lex_InputElement_H_
#define _JC_polyglot_lex_InputElement_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_lex_InputElement$sub_refs	_jc_polyglot_lex_InputElement$sub_refs;
typedef struct _jc_polyglot_lex_InputElement$sub_nonrefs	_jc_polyglot_lex_InputElement$sub_nonrefs;
typedef struct _jc_polyglot_lex_InputElement$refs	_jc_polyglot_lex_InputElement$refs;
typedef struct _jc_polyglot_lex_InputElement$nonrefs	_jc_polyglot_lex_InputElement$nonrefs;
typedef struct _jc_polyglot_lex_InputElement$object	_jc_polyglot_lex_InputElement$object;

typedef const struct _jc_polyglot_lex_InputElement$vmethods	_jc_polyglot_lex_InputElement$vmethods;
typedef const struct _jc_polyglot_lex_InputElement$vtable	_jc_polyglot_lex_InputElement$vtable;
typedef const struct _jc_polyglot_lex_InputElement$vtype	_jc_polyglot_lex_InputElement$vtype;

// Constructors
extern void _jc_polyglot_lex_InputElement$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_lex_InputElement$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_lex_InputElement$vmethods {
};

// Vtable
struct _jc_polyglot_lex_InputElement$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_InputElement$vmethods	polyglot_lex_InputElement;
};

// Vtype
struct _jc_polyglot_lex_InputElement$vtype {
	_jc_type			type;
	_jc_polyglot_lex_InputElement$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_InputElement$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_InputElement$refs {
    _jc_polyglot_lex_InputElement$sub_refs	polyglot_lex_InputElement;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_InputElement$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_InputElement$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_InputElement$sub_nonrefs	polyglot_lex_InputElement;
};

// Object instance structure
struct _jc_polyglot_lex_InputElement$object {
	_jc_polyglot_lex_InputElement$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_InputElement$vtype	*vtype;
	_jc_polyglot_lex_InputElement$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_InputElement$vtype _jc_polyglot_lex_InputElement$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_InputElement, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_InputElement$class_object;

#endif	/* _JC_polyglot_lex_InputElement_H_ */
